``pyramid_jqm``
===============

``pyramid_jqm`` is a package which provides "starter" scaffolding for
creating a `jQuery Mobile <http://jquerymobile.com>`_ Pyramid application.

See http://docs.pylonsproject.org/projects/pyramid_jqm/en/latest/ for
detailed documentation.
